# -*- coding: utf-8 -*-
# Copyright 2023 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .collection import (
    Collection,
    CreateCollectionRequest,
    DeleteCollectionRequest,
    GetCollectionRequest,
    ListCollectionsRequest,
    ListCollectionsResponse,
)
from .integration import (
    CreateIntegrationRequest,
    DeleteIntegrationRequest,
    GetIntegrationRequest,
    Integration,
    IntegrationGoogleDrive,
    IntegrationNCBI,
    ListIntegrationsRequest,
    ListIntegrationsResponse,
    UpdateIntegrationRequest,
)
from .search import (
    Blastn,
    Blastp,
    Blastx,
    DeleteSearchRequest,
    GetSearchRequest,
    Hit,
    ListSearchesRequest,
    ListSearchesResponse,
    Search,
    StartSearchRequest,
    Tblastn,
    Tblastx,
)
from .sequence import (
    BatchCreateSequencesRequest,
    BatchCreateSequencesResponse,
    CreateSequenceRequest,
    CreateSequencesFromFileRequest,
    CreateSequencesFromFileResponse,
    DeleteSequenceRequest,
    GetSequenceRequest,
    ListSequencesRequest,
    ListSequencesResponse,
    Sequence,
    Code,
    FileEncoding,
)

__all__ = (
    'Collection',
    'CreateCollectionRequest',
    'DeleteCollectionRequest',
    'GetCollectionRequest',
    'ListCollectionsRequest',
    'ListCollectionsResponse',
    'CreateIntegrationRequest',
    'DeleteIntegrationRequest',
    'GetIntegrationRequest',
    'Integration',
    'IntegrationGoogleDrive',
    'IntegrationNCBI',
    'ListIntegrationsRequest',
    'ListIntegrationsResponse',
    'UpdateIntegrationRequest',
    'Blastn',
    'Blastp',
    'Blastx',
    'DeleteSearchRequest',
    'GetSearchRequest',
    'Hit',
    'ListSearchesRequest',
    'ListSearchesResponse',
    'Search',
    'StartSearchRequest',
    'Tblastn',
    'Tblastx',
    'BatchCreateSequencesRequest',
    'BatchCreateSequencesResponse',
    'CreateSequenceRequest',
    'CreateSequencesFromFileRequest',
    'CreateSequencesFromFileResponse',
    'DeleteSequenceRequest',
    'GetSequenceRequest',
    'ListSequencesRequest',
    'ListSequencesResponse',
    'Sequence',
    'Code',
    'FileEncoding',
)



# -*- coding: utf-8 -*-
# Copyright 2023 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from seqq.api_v1alpha import gapic_version as package_version

__version__ = package_version.__version__


from .services.seqq_service import SeqqServiceClient
from .services.seqq_service import SeqqServiceAsyncClient

from .types.collection import Collection
from .types.collection import CreateCollectionRequest
from .types.collection import DeleteCollectionRequest
from .types.collection import GetCollectionRequest
from .types.collection import ListCollectionsRequest
from .types.collection import ListCollectionsResponse
from .types.integration import CreateIntegrationRequest
from .types.integration import DeleteIntegrationRequest
from .types.integration import GetIntegrationRequest
from .types.integration import Integration
from .types.integration import IntegrationGoogleDrive
from .types.integration import IntegrationNCBI
from .types.integration import ListIntegrationsRequest
from .types.integration import ListIntegrationsResponse
from .types.integration import UpdateIntegrationRequest
from .types.search import Blastn
from .types.search import Blastp
from .types.search import Blastx
from .types.search import DeleteSearchRequest
from .types.search import GetSearchRequest
from .types.search import Hit
from .types.search import ListSearchesRequest
from .types.search import ListSearchesResponse
from .types.search import Search
from .types.search import StartSearchRequest
from .types.search import Tblastn
from .types.search import Tblastx
from .types.sequence import BatchCreateSequencesRequest
from .types.sequence import BatchCreateSequencesResponse
from .types.sequence import CreateSequenceRequest
from .types.sequence import CreateSequencesFromFileRequest
from .types.sequence import CreateSequencesFromFileResponse
from .types.sequence import DeleteSequenceRequest
from .types.sequence import GetSequenceRequest
from .types.sequence import ListSequencesRequest
from .types.sequence import ListSequencesResponse
from .types.sequence import Sequence
from .types.sequence import Code
from .types.sequence import FileEncoding

__all__ = (
    'SeqqServiceAsyncClient',
'BatchCreateSequencesRequest',
'BatchCreateSequencesResponse',
'Blastn',
'Blastp',
'Blastx',
'Code',
'Collection',
'CreateCollectionRequest',
'CreateIntegrationRequest',
'CreateSequenceRequest',
'CreateSequencesFromFileRequest',
'CreateSequencesFromFileResponse',
'DeleteCollectionRequest',
'DeleteIntegrationRequest',
'DeleteSearchRequest',
'DeleteSequenceRequest',
'FileEncoding',
'GetCollectionRequest',
'GetIntegrationRequest',
'GetSearchRequest',
'GetSequenceRequest',
'Hit',
'Integration',
'IntegrationGoogleDrive',
'IntegrationNCBI',
'ListCollectionsRequest',
'ListCollectionsResponse',
'ListIntegrationsRequest',
'ListIntegrationsResponse',
'ListSearchesRequest',
'ListSearchesResponse',
'ListSequencesRequest',
'ListSequencesResponse',
'Search',
'SeqqServiceClient',
'Sequence',
'StartSearchRequest',
'Tblastn',
'Tblastx',
'UpdateIntegrationRequest',
)



# -*- coding: utf-8 -*-
# Copyright 2023 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from typing import Any, AsyncIterator, Awaitable, Callable, Sequence, Tuple, Optional, Iterator

from seqq.api_v1alpha.types import collection
from seqq.api_v1alpha.types import integration
from seqq.api_v1alpha.types import search
from seqq.api_v1alpha.types import sequence


class ListCollectionsPager:
    """A pager for iterating through ``list_collections`` requests.

    This class thinly wraps an initial
    :class:`seqq.api_v1alpha.types.ListCollectionsResponse` object, and
    provides an ``__iter__`` method to iterate through its
    ``collections`` field.

    If there are more pages, the ``__iter__`` method will make additional
    ``ListCollections`` requests and continue to iterate
    through the ``collections`` field on the
    corresponding responses.

    All the usual :class:`seqq.api_v1alpha.types.ListCollectionsResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """
    def __init__(self,
            method: Callable[..., collection.ListCollectionsResponse],
            request: collection.ListCollectionsRequest,
            response: collection.ListCollectionsResponse,
            *,
            metadata: Sequence[Tuple[str, str]] = ()):
        """Instantiate the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (seqq.api_v1alpha.types.ListCollectionsRequest):
                The initial request object.
            response (seqq.api_v1alpha.types.ListCollectionsResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = collection.ListCollectionsRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    def pages(self) -> Iterator[collection.ListCollectionsResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = self._method(self._request, metadata=self._metadata)
            yield self._response

    def __iter__(self) -> Iterator[collection.Collection]:
        for page in self.pages:
            yield from page.collections

    def __repr__(self) -> str:
        return '{0}<{1!r}>'.format(self.__class__.__name__, self._response)


class ListCollectionsAsyncPager:
    """A pager for iterating through ``list_collections`` requests.

    This class thinly wraps an initial
    :class:`seqq.api_v1alpha.types.ListCollectionsResponse` object, and
    provides an ``__aiter__`` method to iterate through its
    ``collections`` field.

    If there are more pages, the ``__aiter__`` method will make additional
    ``ListCollections`` requests and continue to iterate
    through the ``collections`` field on the
    corresponding responses.

    All the usual :class:`seqq.api_v1alpha.types.ListCollectionsResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """
    def __init__(self,
            method: Callable[..., Awaitable[collection.ListCollectionsResponse]],
            request: collection.ListCollectionsRequest,
            response: collection.ListCollectionsResponse,
            *,
            metadata: Sequence[Tuple[str, str]] = ()):
        """Instantiates the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (seqq.api_v1alpha.types.ListCollectionsRequest):
                The initial request object.
            response (seqq.api_v1alpha.types.ListCollectionsResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = collection.ListCollectionsRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    async def pages(self) -> AsyncIterator[collection.ListCollectionsResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = await self._method(self._request, metadata=self._metadata)
            yield self._response
    def __aiter__(self) -> AsyncIterator[collection.Collection]:
        async def async_generator():
            async for page in self.pages:
                for response in page.collections:
                    yield response

        return async_generator()

    def __repr__(self) -> str:
        return '{0}<{1!r}>'.format(self.__class__.__name__, self._response)


class ListSequencesPager:
    """A pager for iterating through ``list_sequences`` requests.

    This class thinly wraps an initial
    :class:`seqq.api_v1alpha.types.ListSequencesResponse` object, and
    provides an ``__iter__`` method to iterate through its
    ``sequences`` field.

    If there are more pages, the ``__iter__`` method will make additional
    ``ListSequences`` requests and continue to iterate
    through the ``sequences`` field on the
    corresponding responses.

    All the usual :class:`seqq.api_v1alpha.types.ListSequencesResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """
    def __init__(self,
            method: Callable[..., sequence.ListSequencesResponse],
            request: sequence.ListSequencesRequest,
            response: sequence.ListSequencesResponse,
            *,
            metadata: Sequence[Tuple[str, str]] = ()):
        """Instantiate the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (seqq.api_v1alpha.types.ListSequencesRequest):
                The initial request object.
            response (seqq.api_v1alpha.types.ListSequencesResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = sequence.ListSequencesRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    def pages(self) -> Iterator[sequence.ListSequencesResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = self._method(self._request, metadata=self._metadata)
            yield self._response

    def __iter__(self) -> Iterator[sequence.Sequence]:
        for page in self.pages:
            yield from page.sequences

    def __repr__(self) -> str:
        return '{0}<{1!r}>'.format(self.__class__.__name__, self._response)


class ListSequencesAsyncPager:
    """A pager for iterating through ``list_sequences`` requests.

    This class thinly wraps an initial
    :class:`seqq.api_v1alpha.types.ListSequencesResponse` object, and
    provides an ``__aiter__`` method to iterate through its
    ``sequences`` field.

    If there are more pages, the ``__aiter__`` method will make additional
    ``ListSequences`` requests and continue to iterate
    through the ``sequences`` field on the
    corresponding responses.

    All the usual :class:`seqq.api_v1alpha.types.ListSequencesResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """
    def __init__(self,
            method: Callable[..., Awaitable[sequence.ListSequencesResponse]],
            request: sequence.ListSequencesRequest,
            response: sequence.ListSequencesResponse,
            *,
            metadata: Sequence[Tuple[str, str]] = ()):
        """Instantiates the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (seqq.api_v1alpha.types.ListSequencesRequest):
                The initial request object.
            response (seqq.api_v1alpha.types.ListSequencesResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = sequence.ListSequencesRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    async def pages(self) -> AsyncIterator[sequence.ListSequencesResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = await self._method(self._request, metadata=self._metadata)
            yield self._response
    def __aiter__(self) -> AsyncIterator[sequence.Sequence]:
        async def async_generator():
            async for page in self.pages:
                for response in page.sequences:
                    yield response

        return async_generator()

    def __repr__(self) -> str:
        return '{0}<{1!r}>'.format(self.__class__.__name__, self._response)


class ListSearchesPager:
    """A pager for iterating through ``list_searches`` requests.

    This class thinly wraps an initial
    :class:`seqq.api_v1alpha.types.ListSearchesResponse` object, and
    provides an ``__iter__`` method to iterate through its
    ``searches`` field.

    If there are more pages, the ``__iter__`` method will make additional
    ``ListSearches`` requests and continue to iterate
    through the ``searches`` field on the
    corresponding responses.

    All the usual :class:`seqq.api_v1alpha.types.ListSearchesResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """
    def __init__(self,
            method: Callable[..., search.ListSearchesResponse],
            request: search.ListSearchesRequest,
            response: search.ListSearchesResponse,
            *,
            metadata: Sequence[Tuple[str, str]] = ()):
        """Instantiate the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (seqq.api_v1alpha.types.ListSearchesRequest):
                The initial request object.
            response (seqq.api_v1alpha.types.ListSearchesResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = search.ListSearchesRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    def pages(self) -> Iterator[search.ListSearchesResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = self._method(self._request, metadata=self._metadata)
            yield self._response

    def __iter__(self) -> Iterator[search.Search]:
        for page in self.pages:
            yield from page.searches

    def __repr__(self) -> str:
        return '{0}<{1!r}>'.format(self.__class__.__name__, self._response)


class ListSearchesAsyncPager:
    """A pager for iterating through ``list_searches`` requests.

    This class thinly wraps an initial
    :class:`seqq.api_v1alpha.types.ListSearchesResponse` object, and
    provides an ``__aiter__`` method to iterate through its
    ``searches`` field.

    If there are more pages, the ``__aiter__`` method will make additional
    ``ListSearches`` requests and continue to iterate
    through the ``searches`` field on the
    corresponding responses.

    All the usual :class:`seqq.api_v1alpha.types.ListSearchesResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """
    def __init__(self,
            method: Callable[..., Awaitable[search.ListSearchesResponse]],
            request: search.ListSearchesRequest,
            response: search.ListSearchesResponse,
            *,
            metadata: Sequence[Tuple[str, str]] = ()):
        """Instantiates the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (seqq.api_v1alpha.types.ListSearchesRequest):
                The initial request object.
            response (seqq.api_v1alpha.types.ListSearchesResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = search.ListSearchesRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    async def pages(self) -> AsyncIterator[search.ListSearchesResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = await self._method(self._request, metadata=self._metadata)
            yield self._response
    def __aiter__(self) -> AsyncIterator[search.Search]:
        async def async_generator():
            async for page in self.pages:
                for response in page.searches:
                    yield response

        return async_generator()

    def __repr__(self) -> str:
        return '{0}<{1!r}>'.format(self.__class__.__name__, self._response)


class ListIntegrationsPager:
    """A pager for iterating through ``list_integrations`` requests.

    This class thinly wraps an initial
    :class:`seqq.api_v1alpha.types.ListIntegrationsResponse` object, and
    provides an ``__iter__`` method to iterate through its
    ``integrations`` field.

    If there are more pages, the ``__iter__`` method will make additional
    ``ListIntegrations`` requests and continue to iterate
    through the ``integrations`` field on the
    corresponding responses.

    All the usual :class:`seqq.api_v1alpha.types.ListIntegrationsResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """
    def __init__(self,
            method: Callable[..., integration.ListIntegrationsResponse],
            request: integration.ListIntegrationsRequest,
            response: integration.ListIntegrationsResponse,
            *,
            metadata: Sequence[Tuple[str, str]] = ()):
        """Instantiate the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (seqq.api_v1alpha.types.ListIntegrationsRequest):
                The initial request object.
            response (seqq.api_v1alpha.types.ListIntegrationsResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = integration.ListIntegrationsRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    def pages(self) -> Iterator[integration.ListIntegrationsResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = self._method(self._request, metadata=self._metadata)
            yield self._response

    def __iter__(self) -> Iterator[integration.Integration]:
        for page in self.pages:
            yield from page.integrations

    def __repr__(self) -> str:
        return '{0}<{1!r}>'.format(self.__class__.__name__, self._response)


class ListIntegrationsAsyncPager:
    """A pager for iterating through ``list_integrations`` requests.

    This class thinly wraps an initial
    :class:`seqq.api_v1alpha.types.ListIntegrationsResponse` object, and
    provides an ``__aiter__`` method to iterate through its
    ``integrations`` field.

    If there are more pages, the ``__aiter__`` method will make additional
    ``ListIntegrations`` requests and continue to iterate
    through the ``integrations`` field on the
    corresponding responses.

    All the usual :class:`seqq.api_v1alpha.types.ListIntegrationsResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """
    def __init__(self,
            method: Callable[..., Awaitable[integration.ListIntegrationsResponse]],
            request: integration.ListIntegrationsRequest,
            response: integration.ListIntegrationsResponse,
            *,
            metadata: Sequence[Tuple[str, str]] = ()):
        """Instantiates the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (seqq.api_v1alpha.types.ListIntegrationsRequest):
                The initial request object.
            response (seqq.api_v1alpha.types.ListIntegrationsResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = integration.ListIntegrationsRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    async def pages(self) -> AsyncIterator[integration.ListIntegrationsResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = await self._method(self._request, metadata=self._metadata)
            yield self._response
    def __aiter__(self) -> AsyncIterator[integration.Integration]:
        async def async_generator():
            async for page in self.pages:
                for response in page.integrations:
                    yield response

        return async_generator()

    def __repr__(self) -> str:
        return '{0}<{1!r}>'.format(self.__class__.__name__, self._response)



# -*- coding: utf-8 -*-
# Copyright 2023 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from collections import OrderedDict
import functools
import re
from typing import Dict, Mapping, MutableMapping, MutableSequence, Optional, Sequence, Tuple, Type, Union

from seqq.api_v1alpha import gapic_version as package_version

from google.api_core.client_options import ClientOptions
from google.api_core import exceptions as core_exceptions
from google.api_core import gapic_v1
from google.api_core import retry_async as retries
from google.auth import credentials as ga_credentials   # type: ignore
from google.oauth2 import service_account              # type: ignore

try:
    OptionalRetry = Union[retries.AsyncRetry, gapic_v1.method._MethodDefault, None]
except AttributeError:  # pragma: NO COVER
    OptionalRetry = Union[retries.AsyncRetry, object, None]  # type: ignore

from google.protobuf import duration_pb2  # type: ignore
from google.protobuf import field_mask_pb2  # type: ignore
from google.protobuf import timestamp_pb2  # type: ignore
from google.rpc import status_pb2  # type: ignore
from seqq.api_v1alpha.services.seqq_service import pagers
from seqq.api_v1alpha.types import collection
from seqq.api_v1alpha.types import collection as sa_collection
from seqq.api_v1alpha.types import integration
from seqq.api_v1alpha.types import integration as sa_integration
from seqq.api_v1alpha.types import search
from seqq.api_v1alpha.types import search as sa_search
from seqq.api_v1alpha.types import sequence
from seqq.api_v1alpha.types import sequence as sa_sequence
from .transports.base import SeqqServiceTransport, DEFAULT_CLIENT_INFO
from .transports.grpc_asyncio import SeqqServiceGrpcAsyncIOTransport
from .client import SeqqServiceClient


class SeqqServiceAsyncClient:
    """Handles user interactions with the service."""

    _client: SeqqServiceClient

    # Copy defaults from the synchronous client for use here.
    # Note: DEFAULT_ENDPOINT is deprecated. Use _DEFAULT_ENDPOINT_TEMPLATE instead.
    DEFAULT_ENDPOINT = SeqqServiceClient.DEFAULT_ENDPOINT
    DEFAULT_MTLS_ENDPOINT = SeqqServiceClient.DEFAULT_MTLS_ENDPOINT
    _DEFAULT_ENDPOINT_TEMPLATE = SeqqServiceClient._DEFAULT_ENDPOINT_TEMPLATE
    _DEFAULT_UNIVERSE = SeqqServiceClient._DEFAULT_UNIVERSE

    collection_path = staticmethod(SeqqServiceClient.collection_path)
    parse_collection_path = staticmethod(SeqqServiceClient.parse_collection_path)
    integration_path = staticmethod(SeqqServiceClient.integration_path)
    parse_integration_path = staticmethod(SeqqServiceClient.parse_integration_path)
    search_path = staticmethod(SeqqServiceClient.search_path)
    parse_search_path = staticmethod(SeqqServiceClient.parse_search_path)
    sequence_path = staticmethod(SeqqServiceClient.sequence_path)
    parse_sequence_path = staticmethod(SeqqServiceClient.parse_sequence_path)
    common_billing_account_path = staticmethod(SeqqServiceClient.common_billing_account_path)
    parse_common_billing_account_path = staticmethod(SeqqServiceClient.parse_common_billing_account_path)
    common_folder_path = staticmethod(SeqqServiceClient.common_folder_path)
    parse_common_folder_path = staticmethod(SeqqServiceClient.parse_common_folder_path)
    common_organization_path = staticmethod(SeqqServiceClient.common_organization_path)
    parse_common_organization_path = staticmethod(SeqqServiceClient.parse_common_organization_path)
    common_project_path = staticmethod(SeqqServiceClient.common_project_path)
    parse_common_project_path = staticmethod(SeqqServiceClient.parse_common_project_path)
    common_location_path = staticmethod(SeqqServiceClient.common_location_path)
    parse_common_location_path = staticmethod(SeqqServiceClient.parse_common_location_path)

    @classmethod
    def from_service_account_info(cls, info: dict, *args, **kwargs):
        """Creates an instance of this client using the provided credentials
            info.

        Args:
            info (dict): The service account private key info.
            args: Additional arguments to pass to the constructor.
            kwargs: Additional arguments to pass to the constructor.

        Returns:
            SeqqServiceAsyncClient: The constructed client.
        """
        return SeqqServiceClient.from_service_account_info.__func__(SeqqServiceAsyncClient, info, *args, **kwargs)  # type: ignore

    @classmethod
    def from_service_account_file(cls, filename: str, *args, **kwargs):
        """Creates an instance of this client using the provided credentials
            file.

        Args:
            filename (str): The path to the service account private key json
                file.
            args: Additional arguments to pass to the constructor.
            kwargs: Additional arguments to pass to the constructor.

        Returns:
            SeqqServiceAsyncClient: The constructed client.
        """
        return SeqqServiceClient.from_service_account_file.__func__(SeqqServiceAsyncClient, filename, *args, **kwargs)  # type: ignore

    from_service_account_json = from_service_account_file

    @classmethod
    def get_mtls_endpoint_and_cert_source(cls, client_options: Optional[ClientOptions] = None):
        """Return the API endpoint and client cert source for mutual TLS.

        The client cert source is determined in the following order:
        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
        client cert source is None.
        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
        default client cert source exists, use the default one; otherwise the client cert
        source is None.

        The API endpoint is determined in the following order:
        (1) if `client_options.api_endpoint` if provided, use the provided one.
        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
        default mTLS endpoint; if the environment variable is "never", use the default API
        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
        use the default API endpoint.

        More details can be found at https://google.aip.dev/auth/4114.

        Args:
            client_options (google.api_core.client_options.ClientOptions): Custom options for the
                client. Only the `api_endpoint` and `client_cert_source` properties may be used
                in this method.

        Returns:
            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
                client cert source to use.

        Raises:
            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
        """
        return SeqqServiceClient.get_mtls_endpoint_and_cert_source(client_options)  # type: ignore

    @property
    def transport(self) -> SeqqServiceTransport:
        """Returns the transport used by the client instance.

        Returns:
            SeqqServiceTransport: The transport used by the client instance.
        """
        return self._client.transport

    @property
    def api_endpoint(self):
        """Return the API endpoint used by the client instance.

        Returns:
            str: The API endpoint used by the client instance.
        """
        return self._client._api_endpoint

    @property
    def universe_domain(self) -> str:
        """Return the universe domain used by the client instance.

        Returns:
            str: The universe domain used
                by the client instance.
        """
        return self._client._universe_domain

    get_transport_class = functools.partial(type(SeqqServiceClient).get_transport_class, type(SeqqServiceClient))

    def __init__(self, *,
            credentials: Optional[ga_credentials.Credentials] = None,
            transport: Union[str, SeqqServiceTransport] = "grpc_asyncio",
            client_options: Optional[ClientOptions] = None,
            client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
            ) -> None:
        """Instantiates the seqq service async client.

        Args:
            credentials (Optional[google.auth.credentials.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify the application to the service; if none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
            transport (Union[str, ~.SeqqServiceTransport]): The
                transport to use. If set to None, a transport is chosen
                automatically.
            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]):
                Custom options for the client.

                1. The ``api_endpoint`` property can be used to override the
                default endpoint provided by the client when ``transport`` is
                not explicitly provided. Only if this property is not set and
                ``transport`` was not explicitly provided, the endpoint is
                determined by the GOOGLE_API_USE_MTLS_ENDPOINT environment
                variable, which have one of the following values:
                "always" (always use the default mTLS endpoint), "never" (always
                use the default regular endpoint) and "auto" (auto-switch to the
                default mTLS endpoint if client certificate is present; this is
                the default value).

                2. If the GOOGLE_API_USE_CLIENT_CERTIFICATE environment variable
                is "true", then the ``client_cert_source`` property can be used
                to provide a client certificate for mTLS transport. If
                not provided, the default SSL client certificate will be used if
                present. If GOOGLE_API_USE_CLIENT_CERTIFICATE is "false" or not
                set, no client certificate will be used.

                3. The ``universe_domain`` property can be used to override the
                default "googleapis.com" universe. Note that ``api_endpoint``
                property still takes precedence; and ``universe_domain`` is
                currently not supported for mTLS.

            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
                The client info used to send a user-agent string along with
                API requests. If ``None``, then default info will be used.
                Generally, you only need to set this if you're developing
                your own client library.

        Raises:
            google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
                creation failed for any reason.
        """
        self._client = SeqqServiceClient(
            credentials=credentials,
            transport=transport,
            client_options=client_options,
            client_info=client_info,

        )

    async def create_collection(self,
            request: Optional[Union[sa_collection.CreateCollectionRequest, dict]] = None,
            *,
            collection: Optional[sa_collection.Collection] = None,
            collection_id: Optional[str] = None,
            retry: OptionalRetry = gapic_v1.method.DEFAULT,
            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
            metadata: Sequence[Tuple[str, str]] = (),
            ) -> sa_collection.Collection:
        r"""Create a Collection.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from seqq import api_v1alpha

            async def sample_create_collection():
                # Create a client
                client = api_v1alpha.SeqqServiceAsyncClient()

                # Initialize request argument(s)
                request = api_v1alpha.CreateCollectionRequest(
                    collection_id="collection_id_value",
                )

                # Make the request
                response = await client.create_collection(request=request)

                # Handle the response
                print(response)

        Args:
            request (Optional[Union[seqq.api_v1alpha.types.CreateCollectionRequest, dict]]):
                The request object. CreateCollectionRequest is used to
                create a collection.
            collection (:class:`seqq.api_v1alpha.types.Collection`):
                Collection to create. Provide ``collection`` when
                setting ``display_name``.

                This corresponds to the ``collection`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            collection_id (:class:`str`):
                ID of the collection to create. Must
                be unique within the parent project.
                Must be between 3 and 64 characters long
                and can only contain alphanumeric
                characters and hyphens.

                This corresponds to the ``collection_id`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            retry (google.api_core.retry_async.AsyncRetry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            seqq.api_v1alpha.types.Collection:
                Collections contain Sequences,
                Searches, and Integration.

        """
        # Create or coerce a protobuf request object.
        # Quick check: If we got a request object, we should *not* have
        # gotten any keyword arguments that map to the request.
        has_flattened_params = any([collection, collection_id])
        if request is not None and has_flattened_params:
            raise ValueError("If the `request` argument is set, then none of "
                             "the individual field arguments should be set.")

        request = sa_collection.CreateCollectionRequest(request)

        # If we have keyword arguments corresponding to fields on the
        # request, apply these.
        if collection is not None:
            request.collection = collection
        if collection_id is not None:
            request.collection_id = collection_id

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.create_collection,
            default_timeout=None,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Validate the universe domain.
        self._client._validate_universe_domain()

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    async def get_collection(self,
            request: Optional[Union[collection.GetCollectionRequest, dict]] = None,
            *,
            name: Optional[str] = None,
            retry: OptionalRetry = gapic_v1.method.DEFAULT,
            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
            metadata: Sequence[Tuple[str, str]] = (),
            ) -> collection.Collection:
        r"""Get a Collection by its name.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from seqq import api_v1alpha

            async def sample_get_collection():
                # Create a client
                client = api_v1alpha.SeqqServiceAsyncClient()

                # Initialize request argument(s)
                request = api_v1alpha.GetCollectionRequest(
                    name="name_value",
                )

                # Make the request
                response = await client.get_collection(request=request)

                # Handle the response
                print(response)

        Args:
            request (Optional[Union[seqq.api_v1alpha.types.GetCollectionRequest, dict]]):
                The request object. GetCollectionRequest is the request
                message for GetCollection.
            name (:class:`str`):
                The name of the Collection to retrieve. Format:
                ``collections/{collection_id}``.

                This corresponds to the ``name`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            retry (google.api_core.retry_async.AsyncRetry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            seqq.api_v1alpha.types.Collection:
                Collections contain Sequences,
                Searches, and Integration.

        """
        # Create or coerce a protobuf request object.
        # Quick check: If we got a request object, we should *not* have
        # gotten any keyword arguments that map to the request.
        has_flattened_params = any([name])
        if request is not None and has_flattened_params:
            raise ValueError("If the `request` argument is set, then none of "
                             "the individual field arguments should be set.")

        request = collection.GetCollectionRequest(request)

        # If we have keyword arguments corresponding to fields on the
        # request, apply these.
        if name is not None:
            request.name = name

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.get_collection,
            default_timeout=None,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((
                ("name", request.name),
            )),
        )

        # Validate the universe domain.
        self._client._validate_universe_domain()

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    async def list_collections(self,
            request: Optional[Union[collection.ListCollectionsRequest, dict]] = None,
            *,
            retry: OptionalRetry = gapic_v1.method.DEFAULT,
            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
            metadata: Sequence[Tuple[str, str]] = (),
            ) -> pagers.ListCollectionsAsyncPager:
        r"""List Collections.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from seqq import api_v1alpha

            async def sample_list_collections():
                # Create a client
                client = api_v1alpha.SeqqServiceAsyncClient()

                # Initialize request argument(s)
                request = api_v1alpha.ListCollectionsRequest(
                )

                # Make the request
                page_result = client.list_collections(request=request)

                # Handle the response
                async for response in page_result:
                    print(response)

        Args:
            request (Optional[Union[seqq.api_v1alpha.types.ListCollectionsRequest, dict]]):
                The request object. ListCollectionsRequest is a request
                to list collections.
            retry (google.api_core.retry_async.AsyncRetry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            seqq.api_v1alpha.services.seqq_service.pagers.ListCollectionsAsyncPager:
                ListCollectionsResponse is the
                response message for ListCollections.
                Iterating over this object will yield
                results and resolve additional pages
                automatically.

        """
        # Create or coerce a protobuf request object.
        request = collection.ListCollectionsRequest(request)

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.list_collections,
            default_timeout=None,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Validate the universe domain.
        self._client._validate_universe_domain()

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # This method is paged; wrap the response in a pager, which provides
        # an `__aiter__` convenience method.
        response = pagers.ListCollectionsAsyncPager(
            method=rpc,
            request=request,
            response=response,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    async def delete_collection(self,
            request: Optional[Union[collection.DeleteCollectionRequest, dict]] = None,
            *,
            name: Optional[str] = None,
            retry: OptionalRetry = gapic_v1.method.DEFAULT,
            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
            metadata: Sequence[Tuple[str, str]] = (),
            ) -> None:
        r"""Delete a Collection by name.

        This will only delete the Collection if it is empty. To delete a
        Collection and all its child resources, set ``force`` to true.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from seqq import api_v1alpha

            async def sample_delete_collection():
                # Create a client
                client = api_v1alpha.SeqqServiceAsyncClient()

                # Initialize request argument(s)
                request = api_v1alpha.DeleteCollectionRequest(
                    name="name_value",
                )

                # Make the request
                await client.delete_collection(request=request)

        Args:
            request (Optional[Union[seqq.api_v1alpha.types.DeleteCollectionRequest, dict]]):
                The request object. DeleteCollectionRequest is the
                request message for DeleteCollection.
            name (:class:`str`):
                The name of the collection to delete. Format:
                ``collections/{collection_id}``.

                This corresponds to the ``name`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            retry (google.api_core.retry_async.AsyncRetry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        # Create or coerce a protobuf request object.
        # Quick check: If we got a request object, we should *not* have
        # gotten any keyword arguments that map to the request.
        has_flattened_params = any([name])
        if request is not None and has_flattened_params:
            raise ValueError("If the `request` argument is set, then none of "
                             "the individual field arguments should be set.")

        request = collection.DeleteCollectionRequest(request)

        # If we have keyword arguments corresponding to fields on the
        # request, apply these.
        if name is not None:
            request.name = name

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.delete_collection,
            default_timeout=None,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((
                ("name", request.name),
            )),
        )

        # Validate the universe domain.
        self._client._validate_universe_domain()

        # Send the request.
        await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

    async def create_sequence(self,
            request: Optional[Union[sa_sequence.CreateSequenceRequest, dict]] = None,
            *,
            collection: Optional[str] = None,
            sequence: Optional[sa_sequence.Sequence] = None,
            sequence_id: Optional[str] = None,
            retry: OptionalRetry = gapic_v1.method.DEFAULT,
            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
            metadata: Sequence[Tuple[str, str]] = (),
            ) -> sa_sequence.Sequence:
        r"""Create a Sequence in a Collection.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from seqq import api_v1alpha

            async def sample_create_sequence():
                # Create a client
                client = api_v1alpha.SeqqServiceAsyncClient()

                # Initialize request argument(s)
                sequence = api_v1alpha.Sequence()
                sequence.sequence = "sequence_value"

                request = api_v1alpha.CreateSequenceRequest(
                    collection="collection_value",
                    sequence_id="sequence_id_value",
                    sequence=sequence,
                )

                # Make the request
                response = await client.create_sequence(request=request)

                # Handle the response
                print(response)

        Args:
            request (Optional[Union[seqq.api_v1alpha.types.CreateSequenceRequest, dict]]):
                The request object. CreateSequenceRequest is the request
                message for CreateSequence.
            collection (:class:`str`):
                The ``name`` of the Collection to create Sequences in.
                Format: ``collections/{collection_id}``.

                This corresponds to the ``collection`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            sequence (:class:`seqq.api_v1alpha.types.Sequence`):
                The Sequence to create.
                This corresponds to the ``sequence`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            sequence_id (:class:`str`):
                The ID of the Sequence to create.

                This is appended to the Collection name and
                ``/sequences/`` to create the Sequence name.

                For example, if ``collection`` is
                ``collections/my-collection``, and ``sequence_id`` is
                ``my-prefix/my-sequence``, the Sequence name will be
                ``collections/my-collection/sequences/my-prefix/my-sequence``.

                The ``/`` delimiter is encouraged to group Sequences by
                prefix. This is useful in both the UI, where Sequences
                are grouped by folders by ``/``-delimited prefixes, and
                in Searches where a Search can be limited to a subset of
                Sequences by prefix.

                This corresponds to the ``sequence_id`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            retry (google.api_core.retry_async.AsyncRetry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            seqq.api_v1alpha.types.Sequence:
                Sequence is a single entry containing
                nucleotides or amino acids and other
                optional metadata like a description,
                creation time, and taxonomy ID.

        """
        # Create or coerce a protobuf request object.
        # Quick check: If we got a request object, we should *not* have
        # gotten any keyword arguments that map to the request.
        has_flattened_params = any([collection, sequence, sequence_id])
        if request is not None and has_flattened_params:
            raise ValueError("If the `request` argument is set, then none of "
                             "the individual field arguments should be set.")

        request = sa_sequence.CreateSequenceRequest(request)

        # If we have keyword arguments corresponding to fields on the
        # request, apply these.
        if collection is not None:
            request.collection = collection
        if sequence is not None:
            request.sequence = sequence
        if sequence_id is not None:
            request.sequence_id = sequence_id

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.create_sequence,
            default_timeout=None,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((
                ("collection", request.collection),
            )),
        )

        # Validate the universe domain.
        self._client._validate_universe_domain()

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    async def batch_create_sequences(self,
            request: Optional[Union[sequence.BatchCreateSequencesRequest, dict]] = None,
            *,
            collection: Optional[str] = None,
            requests: Optional[MutableSequence[sequence.CreateSequenceRequest]] = None,
            retry: OptionalRetry = gapic_v1.method.DEFAULT,
            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
            metadata: Sequence[Tuple[str, str]] = (),
            ) -> sequence.BatchCreateSequencesResponse:
        r"""Create a batch of Sequences in a Collection.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from seqq import api_v1alpha

            async def sample_batch_create_sequences():
                # Create a client
                client = api_v1alpha.SeqqServiceAsyncClient()

                # Initialize request argument(s)
                requests = api_v1alpha.CreateSequenceRequest()
                requests.collection = "collection_value"
                requests.sequence_id = "sequence_id_value"
                requests.sequence.sequence = "sequence_value"

                request = api_v1alpha.BatchCreateSequencesRequest(
                    requests=requests,
                )

                # Make the request
                response = await client.batch_create_sequences(request=request)

                # Handle the response
                print(response)

        Args:
            request (Optional[Union[seqq.api_v1alpha.types.BatchCreateSequencesRequest, dict]]):
                The request object. BatchCreateSequencesRequest specifies
                how to create a batch of sequences at
                once. Sequences in requests that already
                exist are ignored and not returned in
                the response.
            collection (:class:`str`):
                The ``name`` of the Collection to create Sequences in.
                Format: ``collections/{collection_id}``.

                This corresponds to the ``collection`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            requests (:class:`MutableSequence[seqq.api_v1alpha.types.CreateSequenceRequest]`):
                The request message specifying the
                sequences to create. The maximum length
                is 100.

                This corresponds to the ``requests`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            retry (google.api_core.retry_async.AsyncRetry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            seqq.api_v1alpha.types.BatchCreateSequencesResponse:
                BatchCreateSequencesResponse is the
                response message for
                BatchCreateSequences.

        """
        # Create or coerce a protobuf request object.
        # Quick check: If we got a request object, we should *not* have
        # gotten any keyword arguments that map to the request.
        has_flattened_params = any([collection, requests])
        if request is not None and has_flattened_params:
            raise ValueError("If the `request` argument is set, then none of "
                             "the individual field arguments should be set.")

        request = sequence.BatchCreateSequencesRequest(request)

        # If we have keyword arguments corresponding to fields on the
        # request, apply these.
        if collection is not None:
            request.collection = collection
        if requests:
            request.requests.extend(requests)

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.batch_create_sequences,
            default_timeout=None,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((
                ("collection", request.collection),
            )),
        )

        # Validate the universe domain.
        self._client._validate_universe_domain()

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    async def create_sequences_from_file(self,
            request: Optional[Union[sequence.CreateSequencesFromFileRequest, dict]] = None,
            *,
            collection: Optional[str] = None,
            contents: Optional[bytes] = None,
            retry: OptionalRetry = gapic_v1.method.DEFAULT,
            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
            metadata: Sequence[Tuple[str, str]] = (),
            ) -> sequence.CreateSequencesFromFileResponse:
        r"""Create Sequences in a Collection by parsing a FASTA
        or GenBank file.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from seqq import api_v1alpha

            async def sample_create_sequences_from_file():
                # Create a client
                client = api_v1alpha.SeqqServiceAsyncClient()

                # Initialize request argument(s)
                request = api_v1alpha.CreateSequencesFromFileRequest(
                    collection="collection_value",
                    encoding="GENBANK",
                    contents=b'contents_blob',
                )

                # Make the request
                response = await client.create_sequences_from_file(request=request)

                # Handle the response
                print(response)

        Args:
            request (Optional[Union[seqq.api_v1alpha.types.CreateSequencesFromFileRequest, dict]]):
                The request object. CreateSequencesFromFileRequest
                accepts a file and creates sequences
                from it.
            collection (:class:`str`):
                The ``name`` of the Collection to create Sequences in.
                Format: ``collections/{collection_id}``.

                This corresponds to the ``collection`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            contents (:class:`bytes`):
                Content of the file to parse to
                sequences.

                This corresponds to the ``contents`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            retry (google.api_core.retry_async.AsyncRetry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            seqq.api_v1alpha.types.CreateSequencesFromFileResponse:
                Contains the sequences that were
                created from the file.

        """
        # Create or coerce a protobuf request object.
        # Quick check: If we got a request object, we should *not* have
        # gotten any keyword arguments that map to the request.
        has_flattened_params = any([collection, contents])
        if request is not None and has_flattened_params:
            raise ValueError("If the `request` argument is set, then none of "
                             "the individual field arguments should be set.")

        request = sequence.CreateSequencesFromFileRequest(request)

        # If we have keyword arguments corresponding to fields on the
        # request, apply these.
        if collection is not None:
            request.collection = collection
        if contents is not None:
            request.contents = contents

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.create_sequences_from_file,
            default_timeout=None,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Validate the universe domain.
        self._client._validate_universe_domain()

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    async def get_sequence(self,
            request: Optional[Union[sequence.GetSequenceRequest, dict]] = None,
            *,
            name: Optional[str] = None,
            retry: OptionalRetry = gapic_v1.method.DEFAULT,
            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
            metadata: Sequence[Tuple[str, str]] = (),
            ) -> sequence.Sequence:
        r"""Get a Sequence by name.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from seqq import api_v1alpha

            async def sample_get_sequence():
                # Create a client
                client = api_v1alpha.SeqqServiceAsyncClient()

                # Initialize request argument(s)
                request = api_v1alpha.GetSequenceRequest(
                    name="name_value",
                )

                # Make the request
                response = await client.get_sequence(request=request)

                # Handle the response
                print(response)

        Args:
            request (Optional[Union[seqq.api_v1alpha.types.GetSequenceRequest, dict]]):
                The request object. GetSequenceRequest is the request
                message for GetSequence.
            name (:class:`str`):
                The ``name`` of the Sequence to retrieve. Format:
                ``collections/{collection_id}/sequences/{sequence_id}``.

                This corresponds to the ``name`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            retry (google.api_core.retry_async.AsyncRetry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            seqq.api_v1alpha.types.Sequence:
                Sequence is a single entry containing
                nucleotides or amino acids and other
                optional metadata like a description,
                creation time, and taxonomy ID.

        """
        # Create or coerce a protobuf request object.
        # Quick check: If we got a request object, we should *not* have
        # gotten any keyword arguments that map to the request.
        has_flattened_params = any([name])
        if request is not None and has_flattened_params:
            raise ValueError("If the `request` argument is set, then none of "
                             "the individual field arguments should be set.")

        request = sequence.GetSequenceRequest(request)

        # If we have keyword arguments corresponding to fields on the
        # request, apply these.
        if name is not None:
            request.name = name

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.get_sequence,
            default_timeout=None,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((
                ("name", request.name),
            )),
        )

        # Validate the universe domain.
        self._client._validate_universe_domain()

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    async def list_sequences(self,
            request: Optional[Union[sequence.ListSequencesRequest, dict]] = None,
            *,
            collection: Optional[str] = None,
            retry: OptionalRetry = gapic_v1.method.DEFAULT,
            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
            metadata: Sequence[Tuple[str, str]] = (),
            ) -> pagers.ListSequencesAsyncPager:
        r"""List Sequences in a Collection.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from seqq import api_v1alpha

            async def sample_list_sequences():
                # Create a client
                client = api_v1alpha.SeqqServiceAsyncClient()

                # Initialize request argument(s)
                request = api_v1alpha.ListSequencesRequest(
                    collection="collection_value",
                )

                # Make the request
                page_result = client.list_sequences(request=request)

                # Handle the response
                async for response in page_result:
                    print(response)

        Args:
            request (Optional[Union[seqq.api_v1alpha.types.ListSequencesRequest, dict]]):
                The request object. ListSequencesRequest is a request to
                list sequences.
            collection (:class:`str`):
                The ``name`` of the Collection to list Sequences from.
                Format: ``collections/{collection_id}``.

                This corresponds to the ``collection`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            retry (google.api_core.retry_async.AsyncRetry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            seqq.api_v1alpha.services.seqq_service.pagers.ListSequencesAsyncPager:
                ListSequencesResponse is the response
                message for ListSequences.
                Iterating over this object will yield
                results and resolve additional pages
                automatically.

        """
        # Create or coerce a protobuf request object.
        # Quick check: If we got a request object, we should *not* have
        # gotten any keyword arguments that map to the request.
        has_flattened_params = any([collection])
        if request is not None and has_flattened_params:
            raise ValueError("If the `request` argument is set, then none of "
                             "the individual field arguments should be set.")

        request = sequence.ListSequencesRequest(request)

        # If we have keyword arguments corresponding to fields on the
        # request, apply these.
        if collection is not None:
            request.collection = collection

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.list_sequences,
            default_timeout=None,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((
                ("collection", request.collection),
            )),
        )

        # Validate the universe domain.
        self._client._validate_universe_domain()

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # This method is paged; wrap the response in a pager, which provides
        # an `__aiter__` convenience method.
        response = pagers.ListSequencesAsyncPager(
            method=rpc,
            request=request,
            response=response,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    async def delete_sequence(self,
            request: Optional[Union[sequence.DeleteSequenceRequest, dict]] = None,
            *,
            name: Optional[str] = None,
            retry: OptionalRetry = gapic_v1.method.DEFAULT,
            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
            metadata: Sequence[Tuple[str, str]] = (),
            ) -> None:
        r"""Delete a Sequence by name.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from seqq import api_v1alpha

            async def sample_delete_sequence():
                # Create a client
                client = api_v1alpha.SeqqServiceAsyncClient()

                # Initialize request argument(s)
                request = api_v1alpha.DeleteSequenceRequest(
                    name="name_value",
                )

                # Make the request
                await client.delete_sequence(request=request)

        Args:
            request (Optional[Union[seqq.api_v1alpha.types.DeleteSequenceRequest, dict]]):
                The request object. DeleteSequenceRequest is the request
                message for DeleteSequence.
            name (:class:`str`):
                The name of the Sequence to delete. Format:
                ``collections/{collection_id}/sequences/{sequence_id}``.

                This corresponds to the ``name`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            retry (google.api_core.retry_async.AsyncRetry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        # Create or coerce a protobuf request object.
        # Quick check: If we got a request object, we should *not* have
        # gotten any keyword arguments that map to the request.
        has_flattened_params = any([name])
        if request is not None and has_flattened_params:
            raise ValueError("If the `request` argument is set, then none of "
                             "the individual field arguments should be set.")

        request = sequence.DeleteSequenceRequest(request)

        # If we have keyword arguments corresponding to fields on the
        # request, apply these.
        if name is not None:
            request.name = name

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.delete_sequence,
            default_timeout=None,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((
                ("name", request.name),
            )),
        )

        # Validate the universe domain.
        self._client._validate_universe_domain()

        # Send the request.
        await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

    async def start_search(self,
            request: Optional[Union[sa_search.StartSearchRequest, dict]] = None,
            *,
            collection: Optional[str] = None,
            search: Optional[sa_search.Search] = None,
            retry: OptionalRetry = gapic_v1.method.DEFAULT,
            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
            metadata: Sequence[Tuple[str, str]] = (),
            ) -> sa_search.Search:
        r"""Start a Search asynchronously.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from seqq import api_v1alpha

            async def sample_start_search():
                # Create a client
                client = api_v1alpha.SeqqServiceAsyncClient()

                # Initialize request argument(s)
                search = api_v1alpha.Search()
                search.query = "query_value"

                request = api_v1alpha.StartSearchRequest(
                    collection="collection_value",
                    search=search,
                )

                # Make the request
                response = await client.start_search(request=request)

                # Handle the response
                print(response)

        Args:
            request (Optional[Union[seqq.api_v1alpha.types.StartSearchRequest, dict]]):
                The request object. StartSearchRequest is the request
                message for Search.
            collection (:class:`str`):
                The ``name`` of the Collection to search against. Only
                Sequences in this Collection are queried. Format:
                ``collections/{collection_id}``.

                This corresponds to the ``collection`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            search (:class:`seqq.api_v1alpha.types.Search`):
                The search parameters to use.
                This corresponds to the ``search`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            retry (google.api_core.retry_async.AsyncRetry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            seqq.api_v1alpha.types.Search:
                A Search of the Sequences in a Collection.

                   On creation, Searches direct seqq to start a query
                   against a Collection using a chosen program. On
                   reads, Searches contain the results of the query,
                   including its current state and any hits.

        """
        # Create or coerce a protobuf request object.
        # Quick check: If we got a request object, we should *not* have
        # gotten any keyword arguments that map to the request.
        has_flattened_params = any([collection, search])
        if request is not None and has_flattened_params:
            raise ValueError("If the `request` argument is set, then none of "
                             "the individual field arguments should be set.")

        request = sa_search.StartSearchRequest(request)

        # If we have keyword arguments corresponding to fields on the
        # request, apply these.
        if collection is not None:
            request.collection = collection
        if search is not None:
            request.search = search

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.start_search,
            default_timeout=None,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((
                ("collection", request.collection),
            )),
        )

        # Validate the universe domain.
        self._client._validate_universe_domain()

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    async def get_search(self,
            request: Optional[Union[search.GetSearchRequest, dict]] = None,
            *,
            name: Optional[str] = None,
            retry: OptionalRetry = gapic_v1.method.DEFAULT,
            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
            metadata: Sequence[Tuple[str, str]] = (),
            ) -> search.Search:
        r"""Get a Search by name.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from seqq import api_v1alpha

            async def sample_get_search():
                # Create a client
                client = api_v1alpha.SeqqServiceAsyncClient()

                # Initialize request argument(s)
                request = api_v1alpha.GetSearchRequest(
                    name="name_value",
                )

                # Make the request
                response = await client.get_search(request=request)

                # Handle the response
                print(response)

        Args:
            request (Optional[Union[seqq.api_v1alpha.types.GetSearchRequest, dict]]):
                The request object. GetSearchRequest gets a currently
                ongoing search.
            name (:class:`str`):
                The name of the Search to retrieve. Format:
                ``collections/{collection_id}/searches/{search_id}``.

                This corresponds to the ``name`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            retry (google.api_core.retry_async.AsyncRetry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            seqq.api_v1alpha.types.Search:
                A Search of the Sequences in a Collection.

                   On creation, Searches direct seqq to start a query
                   against a Collection using a chosen program. On
                   reads, Searches contain the results of the query,
                   including its current state and any hits.

        """
        # Create or coerce a protobuf request object.
        # Quick check: If we got a request object, we should *not* have
        # gotten any keyword arguments that map to the request.
        has_flattened_params = any([name])
        if request is not None and has_flattened_params:
            raise ValueError("If the `request` argument is set, then none of "
                             "the individual field arguments should be set.")

        request = search.GetSearchRequest(request)

        # If we have keyword arguments corresponding to fields on the
        # request, apply these.
        if name is not None:
            request.name = name

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.get_search,
            default_timeout=None,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((
                ("name", request.name),
            )),
        )

        # Validate the universe domain.
        self._client._validate_universe_domain()

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    async def list_searches(self,
            request: Optional[Union[search.ListSearchesRequest, dict]] = None,
            *,
            collection: Optional[str] = None,
            retry: OptionalRetry = gapic_v1.method.DEFAULT,
            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
            metadata: Sequence[Tuple[str, str]] = (),
            ) -> pagers.ListSearchesAsyncPager:
        r"""List Searches in a Collection.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from seqq import api_v1alpha

            async def sample_list_searches():
                # Create a client
                client = api_v1alpha.SeqqServiceAsyncClient()

                # Initialize request argument(s)
                request = api_v1alpha.ListSearchesRequest(
                    collection="collection_value",
                )

                # Make the request
                page_result = client.list_searches(request=request)

                # Handle the response
                async for response in page_result:
                    print(response)

        Args:
            request (Optional[Union[seqq.api_v1alpha.types.ListSearchesRequest, dict]]):
                The request object. ListSearchesRequest lists searches.
            collection (:class:`str`):
                The ``name`` of the Collection to list Searches from.
                Format: ``collections/{collection_id}``.

                This corresponds to the ``collection`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            retry (google.api_core.retry_async.AsyncRetry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            seqq.api_v1alpha.services.seqq_service.pagers.ListSearchesAsyncPager:
                ListSearchesResponse is the response
                message for ListSequences.
                Iterating over this object will yield
                results and resolve additional pages
                automatically.

        """
        # Create or coerce a protobuf request object.
        # Quick check: If we got a request object, we should *not* have
        # gotten any keyword arguments that map to the request.
        has_flattened_params = any([collection])
        if request is not None and has_flattened_params:
            raise ValueError("If the `request` argument is set, then none of "
                             "the individual field arguments should be set.")

        request = search.ListSearchesRequest(request)

        # If we have keyword arguments corresponding to fields on the
        # request, apply these.
        if collection is not None:
            request.collection = collection

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.list_searches,
            default_timeout=None,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((
                ("collection", request.collection),
            )),
        )

        # Validate the universe domain.
        self._client._validate_universe_domain()

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # This method is paged; wrap the response in a pager, which provides
        # an `__aiter__` convenience method.
        response = pagers.ListSearchesAsyncPager(
            method=rpc,
            request=request,
            response=response,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    async def delete_search(self,
            request: Optional[Union[search.DeleteSearchRequest, dict]] = None,
            *,
            name: Optional[str] = None,
            retry: OptionalRetry = gapic_v1.method.DEFAULT,
            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
            metadata: Sequence[Tuple[str, str]] = (),
            ) -> None:
        r"""Delete a Search by name.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from seqq import api_v1alpha

            async def sample_delete_search():
                # Create a client
                client = api_v1alpha.SeqqServiceAsyncClient()

                # Initialize request argument(s)
                request = api_v1alpha.DeleteSearchRequest(
                    name="name_value",
                )

                # Make the request
                await client.delete_search(request=request)

        Args:
            request (Optional[Union[seqq.api_v1alpha.types.DeleteSearchRequest, dict]]):
                The request object. DeleteSearchRequest deletes a search.
            name (:class:`str`):
                The name of the Search to delete. Format:
                ``collections/{collection_id}/searches/{search_id}``.

                This corresponds to the ``name`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            retry (google.api_core.retry_async.AsyncRetry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        # Create or coerce a protobuf request object.
        # Quick check: If we got a request object, we should *not* have
        # gotten any keyword arguments that map to the request.
        has_flattened_params = any([name])
        if request is not None and has_flattened_params:
            raise ValueError("If the `request` argument is set, then none of "
                             "the individual field arguments should be set.")

        request = search.DeleteSearchRequest(request)

        # If we have keyword arguments corresponding to fields on the
        # request, apply these.
        if name is not None:
            request.name = name

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.delete_search,
            default_timeout=None,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((
                ("name", request.name),
            )),
        )

        # Validate the universe domain.
        self._client._validate_universe_domain()

        # Send the request.
        await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

    async def create_integration(self,
            request: Optional[Union[sa_integration.CreateIntegrationRequest, dict]] = None,
            *,
            collection: Optional[str] = None,
            integration: Optional[sa_integration.Integration] = None,
            integration_id: Optional[str] = None,
            retry: OptionalRetry = gapic_v1.method.DEFAULT,
            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
            metadata: Sequence[Tuple[str, str]] = (),
            ) -> sa_integration.Integration:
        r"""Create an Integration.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from seqq import api_v1alpha

            async def sample_create_integration():
                # Create a client
                client = api_v1alpha.SeqqServiceAsyncClient()

                # Initialize request argument(s)
                integration = api_v1alpha.Integration()
                integration.ncbi.manifest = "manifest_value"
                integration.collection = "collection_value"

                request = api_v1alpha.CreateIntegrationRequest(
                    collection="collection_value",
                    integration=integration,
                )

                # Make the request
                response = await client.create_integration(request=request)

                # Handle the response
                print(response)

        Args:
            request (Optional[Union[seqq.api_v1alpha.types.CreateIntegrationRequest, dict]]):
                The request object. CreateIntegrationRequest is a request
                to create a new integration.
            collection (:class:`str`):
                The name of the integration to
                create.

                This corresponds to the ``collection`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            integration (:class:`seqq.api_v1alpha.types.Integration`):
                The integration to create.
                This corresponds to the ``integration`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            integration_id (:class:`str`):
                ID of the integration to create.
                This corresponds to the ``integration_id`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            retry (google.api_core.retry_async.AsyncRetry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            seqq.api_v1alpha.types.Integration:
                Integrations instruct seqq to import
                Sequences from external sources.

        """
        # Create or coerce a protobuf request object.
        # Quick check: If we got a request object, we should *not* have
        # gotten any keyword arguments that map to the request.
        has_flattened_params = any([collection, integration, integration_id])
        if request is not None and has_flattened_params:
            raise ValueError("If the `request` argument is set, then none of "
                             "the individual field arguments should be set.")

        request = sa_integration.CreateIntegrationRequest(request)

        # If we have keyword arguments corresponding to fields on the
        # request, apply these.
        if collection is not None:
            request.collection = collection
        if integration is not None:
            request.integration = integration
        if integration_id is not None:
            request.integration_id = integration_id

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.create_integration,
            default_timeout=None,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((
                ("collection", request.collection),
            )),
        )

        # Validate the universe domain.
        self._client._validate_universe_domain()

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    async def get_integration(self,
            request: Optional[Union[integration.GetIntegrationRequest, dict]] = None,
            *,
            name: Optional[str] = None,
            retry: OptionalRetry = gapic_v1.method.DEFAULT,
            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
            metadata: Sequence[Tuple[str, str]] = (),
            ) -> integration.Integration:
        r"""Get an Integration by name.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from seqq import api_v1alpha

            async def sample_get_integration():
                # Create a client
                client = api_v1alpha.SeqqServiceAsyncClient()

                # Initialize request argument(s)
                request = api_v1alpha.GetIntegrationRequest(
                    name="name_value",
                )

                # Make the request
                response = await client.get_integration(request=request)

                # Handle the response
                print(response)

        Args:
            request (Optional[Union[seqq.api_v1alpha.types.GetIntegrationRequest, dict]]):
                The request object. GetIntegrationRequest is the request
                message for getting an integration.
            name (:class:`str`):
                The name of the integration to
                retrieve.

                This corresponds to the ``name`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            retry (google.api_core.retry_async.AsyncRetry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            seqq.api_v1alpha.types.Integration:
                Integrations instruct seqq to import
                Sequences from external sources.

        """
        # Create or coerce a protobuf request object.
        # Quick check: If we got a request object, we should *not* have
        # gotten any keyword arguments that map to the request.
        has_flattened_params = any([name])
        if request is not None and has_flattened_params:
            raise ValueError("If the `request` argument is set, then none of "
                             "the individual field arguments should be set.")

        request = integration.GetIntegrationRequest(request)

        # If we have keyword arguments corresponding to fields on the
        # request, apply these.
        if name is not None:
            request.name = name

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.get_integration,
            default_timeout=None,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((
                ("name", request.name),
            )),
        )

        # Validate the universe domain.
        self._client._validate_universe_domain()

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    async def update_integration(self,
            request: Optional[Union[sa_integration.UpdateIntegrationRequest, dict]] = None,
            *,
            integration: Optional[sa_integration.Integration] = None,
            update_mask: Optional[field_mask_pb2.FieldMask] = None,
            retry: OptionalRetry = gapic_v1.method.DEFAULT,
            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
            metadata: Sequence[Tuple[str, str]] = (),
            ) -> sa_integration.Integration:
        r"""Update an Integration.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from seqq import api_v1alpha

            async def sample_update_integration():
                # Create a client
                client = api_v1alpha.SeqqServiceAsyncClient()

                # Initialize request argument(s)
                integration = api_v1alpha.Integration()
                integration.ncbi.manifest = "manifest_value"
                integration.collection = "collection_value"

                request = api_v1alpha.UpdateIntegrationRequest(
                    integration=integration,
                )

                # Make the request
                response = await client.update_integration(request=request)

                # Handle the response
                print(response)

        Args:
            request (Optional[Union[seqq.api_v1alpha.types.UpdateIntegrationRequest, dict]]):
                The request object. UpdateIntegrationRequest is a request
                to update an integration.
            integration (:class:`seqq.api_v1alpha.types.Integration`):
                The integration to update.
                This corresponds to the ``integration`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            update_mask (:class:`google.protobuf.field_mask_pb2.FieldMask`):
                The list of fields to update.
                This corresponds to the ``update_mask`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            retry (google.api_core.retry_async.AsyncRetry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            seqq.api_v1alpha.types.Integration:
                Integrations instruct seqq to import
                Sequences from external sources.

        """
        # Create or coerce a protobuf request object.
        # Quick check: If we got a request object, we should *not* have
        # gotten any keyword arguments that map to the request.
        has_flattened_params = any([integration, update_mask])
        if request is not None and has_flattened_params:
            raise ValueError("If the `request` argument is set, then none of "
                             "the individual field arguments should be set.")

        request = sa_integration.UpdateIntegrationRequest(request)

        # If we have keyword arguments corresponding to fields on the
        # request, apply these.
        if integration is not None:
            request.integration = integration
        if update_mask is not None:
            request.update_mask = update_mask

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.update_integration,
            default_timeout=None,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((
                ("integration.name", request.integration.name),
            )),
        )

        # Validate the universe domain.
        self._client._validate_universe_domain()

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    async def list_integrations(self,
            request: Optional[Union[integration.ListIntegrationsRequest, dict]] = None,
            *,
            collection: Optional[str] = None,
            retry: OptionalRetry = gapic_v1.method.DEFAULT,
            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
            metadata: Sequence[Tuple[str, str]] = (),
            ) -> pagers.ListIntegrationsAsyncPager:
        r"""List Integrations in a Collection.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from seqq import api_v1alpha

            async def sample_list_integrations():
                # Create a client
                client = api_v1alpha.SeqqServiceAsyncClient()

                # Initialize request argument(s)
                request = api_v1alpha.ListIntegrationsRequest(
                    collection="collection_value",
                )

                # Make the request
                page_result = client.list_integrations(request=request)

                # Handle the response
                async for response in page_result:
                    print(response)

        Args:
            request (Optional[Union[seqq.api_v1alpha.types.ListIntegrationsRequest, dict]]):
                The request object. ListIntegrationsRequest is a request
                to list integrations.
            collection (:class:`str`):
                The collection collection of the
                integrations to retrieve.

                This corresponds to the ``collection`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            retry (google.api_core.retry_async.AsyncRetry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            seqq.api_v1alpha.services.seqq_service.pagers.ListIntegrationsAsyncPager:
                ListIntegrationsResponse holds a list
                of integrations.
                Iterating over this object will yield
                results and resolve additional pages
                automatically.

        """
        # Create or coerce a protobuf request object.
        # Quick check: If we got a request object, we should *not* have
        # gotten any keyword arguments that map to the request.
        has_flattened_params = any([collection])
        if request is not None and has_flattened_params:
            raise ValueError("If the `request` argument is set, then none of "
                             "the individual field arguments should be set.")

        request = integration.ListIntegrationsRequest(request)

        # If we have keyword arguments corresponding to fields on the
        # request, apply these.
        if collection is not None:
            request.collection = collection

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.list_integrations,
            default_timeout=None,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((
                ("collection", request.collection),
            )),
        )

        # Validate the universe domain.
        self._client._validate_universe_domain()

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # This method is paged; wrap the response in a pager, which provides
        # an `__aiter__` convenience method.
        response = pagers.ListIntegrationsAsyncPager(
            method=rpc,
            request=request,
            response=response,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    async def delete_integration(self,
            request: Optional[Union[integration.DeleteIntegrationRequest, dict]] = None,
            *,
            name: Optional[str] = None,
            retry: OptionalRetry = gapic_v1.method.DEFAULT,
            timeout: Union[float, object] = gapic_v1.method.DEFAULT,
            metadata: Sequence[Tuple[str, str]] = (),
            ) -> None:
        r"""Delete an Integration by name.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from seqq import api_v1alpha

            async def sample_delete_integration():
                # Create a client
                client = api_v1alpha.SeqqServiceAsyncClient()

                # Initialize request argument(s)
                request = api_v1alpha.DeleteIntegrationRequest(
                    name="name_value",
                )

                # Make the request
                await client.delete_integration(request=request)

        Args:
            request (Optional[Union[seqq.api_v1alpha.types.DeleteIntegrationRequest, dict]]):
                The request object. DeleteIntegrationRequest is the
                request message for DeleteIntegration.
            name (:class:`str`):
                The name of the Integration to delete. Format is
                ``collections/{collection_id}/integrations/{integration_id}``.

                This corresponds to the ``name`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            retry (google.api_core.retry_async.AsyncRetry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        # Create or coerce a protobuf request object.
        # Quick check: If we got a request object, we should *not* have
        # gotten any keyword arguments that map to the request.
        has_flattened_params = any([name])
        if request is not None and has_flattened_params:
            raise ValueError("If the `request` argument is set, then none of "
                             "the individual field arguments should be set.")

        request = integration.DeleteIntegrationRequest(request)

        # If we have keyword arguments corresponding to fields on the
        # request, apply these.
        if name is not None:
            request.name = name

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.delete_integration,
            default_timeout=None,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((
                ("name", request.name),
            )),
        )

        # Validate the universe domain.
        self._client._validate_universe_domain()

        # Send the request.
        await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

    async def __aenter__(self) -> "SeqqServiceAsyncClient":
        return self

    async def __aexit__(self, exc_type, exc, tb):
        await self.transport.close()

DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(gapic_version=package_version.__version__)


__all__ = (
    "SeqqServiceAsyncClient",
)



# -*- coding: utf-8 -*-
# Copyright 2023 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from seqq.api import gapic_version as package_version

__version__ = package_version.__version__


from seqq.api_v1alpha.services.seqq_service.client import SeqqServiceClient
from seqq.api_v1alpha.services.seqq_service.async_client import SeqqServiceAsyncClient

from seqq.api_v1alpha.types.collection import Collection
from seqq.api_v1alpha.types.collection import CreateCollectionRequest
from seqq.api_v1alpha.types.collection import DeleteCollectionRequest
from seqq.api_v1alpha.types.collection import GetCollectionRequest
from seqq.api_v1alpha.types.collection import ListCollectionsRequest
from seqq.api_v1alpha.types.collection import ListCollectionsResponse
from seqq.api_v1alpha.types.integration import CreateIntegrationRequest
from seqq.api_v1alpha.types.integration import DeleteIntegrationRequest
from seqq.api_v1alpha.types.integration import GetIntegrationRequest
from seqq.api_v1alpha.types.integration import Integration
from seqq.api_v1alpha.types.integration import IntegrationGoogleDrive
from seqq.api_v1alpha.types.integration import IntegrationNCBI
from seqq.api_v1alpha.types.integration import ListIntegrationsRequest
from seqq.api_v1alpha.types.integration import ListIntegrationsResponse
from seqq.api_v1alpha.types.integration import UpdateIntegrationRequest
from seqq.api_v1alpha.types.search import Blastn
from seqq.api_v1alpha.types.search import Blastp
from seqq.api_v1alpha.types.search import Blastx
from seqq.api_v1alpha.types.search import DeleteSearchRequest
from seqq.api_v1alpha.types.search import GetSearchRequest
from seqq.api_v1alpha.types.search import Hit
from seqq.api_v1alpha.types.search import ListSearchesRequest
from seqq.api_v1alpha.types.search import ListSearchesResponse
from seqq.api_v1alpha.types.search import Search
from seqq.api_v1alpha.types.search import StartSearchRequest
from seqq.api_v1alpha.types.search import Tblastn
from seqq.api_v1alpha.types.search import Tblastx
from seqq.api_v1alpha.types.sequence import BatchCreateSequencesRequest
from seqq.api_v1alpha.types.sequence import BatchCreateSequencesResponse
from seqq.api_v1alpha.types.sequence import CreateSequenceRequest
from seqq.api_v1alpha.types.sequence import CreateSequencesFromFileRequest
from seqq.api_v1alpha.types.sequence import CreateSequencesFromFileResponse
from seqq.api_v1alpha.types.sequence import DeleteSequenceRequest
from seqq.api_v1alpha.types.sequence import GetSequenceRequest
from seqq.api_v1alpha.types.sequence import ListSequencesRequest
from seqq.api_v1alpha.types.sequence import ListSequencesResponse
from seqq.api_v1alpha.types.sequence import Sequence
from seqq.api_v1alpha.types.sequence import Code
from seqq.api_v1alpha.types.sequence import FileEncoding

__all__ = ('SeqqServiceClient',
    'SeqqServiceAsyncClient',
    'Collection',
    'CreateCollectionRequest',
    'DeleteCollectionRequest',
    'GetCollectionRequest',
    'ListCollectionsRequest',
    'ListCollectionsResponse',
    'CreateIntegrationRequest',
    'DeleteIntegrationRequest',
    'GetIntegrationRequest',
    'Integration',
    'IntegrationGoogleDrive',
    'IntegrationNCBI',
    'ListIntegrationsRequest',
    'ListIntegrationsResponse',
    'UpdateIntegrationRequest',
    'Blastn',
    'Blastp',
    'Blastx',
    'DeleteSearchRequest',
    'GetSearchRequest',
    'Hit',
    'ListSearchesRequest',
    'ListSearchesResponse',
    'Search',
    'StartSearchRequest',
    'Tblastn',
    'Tblastx',
    'BatchCreateSequencesRequest',
    'BatchCreateSequencesResponse',
    'CreateSequenceRequest',
    'CreateSequencesFromFileRequest',
    'CreateSequencesFromFileResponse',
    'DeleteSequenceRequest',
    'GetSequenceRequest',
    'ListSequencesRequest',
    'ListSequencesResponse',
    'Sequence',
    'Code',
    'FileEncoding',
)



# -*- coding: utf-8 -*-
# Copyright 2023 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

from google.protobuf import field_mask_pb2  # type: ignore


__protobuf__ = proto.module(
    package='seqq.api.v1alpha',
    manifest={
        'Integration',
        'IntegrationNCBI',
        'IntegrationGoogleDrive',
        'CreateIntegrationRequest',
        'UpdateIntegrationRequest',
        'GetIntegrationRequest',
        'ListIntegrationsRequest',
        'ListIntegrationsResponse',
        'DeleteIntegrationRequest',
    },
)


class Integration(proto.Message):
    r"""Integrations instruct seqq to import Sequences from external
    sources.

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        collection (str):
            The name of the Collection that the Integration imports
            Sequences to. Format is ``collections/{collection_id}``.
        name (str):
            A globally unique name of the Integration. Format is
            ``collections/{collection_id}/integrations/{integration_id}``.
        sequence_id_prefix (str):
            A prefix that is prepended to all Sequence
            IDs added to the Collection.
            For example, if "proteins/flourescent" is
            imported to a Collection "my-collection", and a
            Sequence with an ID of "GFP" is imported, the
            Sequence name will be
            "collections/my-collection/sequences/proteins/flourescent/GFP".
        etag (str):
            An opaque, server-assigned value that is the
            hash of all fields in the Integration. Each
            change to an integration changes the Etag value.
        ncbi (seqq.api_v1alpha.types.IntegrationNCBI):
            NCBI integration.

            This field is a member of `oneof`_ ``import``.
        google_drive (seqq.api_v1alpha.types.IntegrationGoogleDrive):
            Google Drive integration.

            This field is a member of `oneof`_ ``import``.
    """

    collection: str = proto.Field(
        proto.STRING,
        number=1,
    )
    name: str = proto.Field(
        proto.STRING,
        number=2,
    )
    sequence_id_prefix: str = proto.Field(
        proto.STRING,
        number=3,
    )
    etag: str = proto.Field(
        proto.STRING,
        number=4,
    )
    ncbi: 'IntegrationNCBI' = proto.Field(
        proto.MESSAGE,
        number=5,
        oneof='import',
        message='IntegrationNCBI',
    )
    google_drive: 'IntegrationGoogleDrive' = proto.Field(
        proto.MESSAGE,
        number=6,
        oneof='import',
        message='IntegrationGoogleDrive',
    )


class IntegrationNCBI(proto.Message):
    r"""NCBI integration.

    Attributes:
        manifest (str):
            The URL of an NCBI manifest to import
            Sequences from. These are from the BLAST FTP
            website. For example,
            "https://ftp.ncbi.nlm.nih.gov/blast/db/taxdb-metadata.json"
            imports Sequences from the NCBI Taxonomy
            database.
        uploads (MutableMapping[str, int]):
            A map from file name to the count of
            sequences uploaded from that file. Files do not
            change in NCBI. This field is set by the server
            so integrations can skip sequence uploading if
            the sequences has already been uploaded. These
            are set when we fail to upload a single sequence
            within the file.
    """

    manifest: str = proto.Field(
        proto.STRING,
        number=1,
    )
    uploads: MutableMapping[str, int] = proto.MapField(
        proto.STRING,
        proto.INT64,
        number=2,
    )


class IntegrationGoogleDrive(proto.Message):
    r"""Google Drive integration.

    Attributes:
        service_account_credentials (bytes):
            Base64 encoded credentials for the service
            account authorized to list sequences in Google
            Drive.
    """

    service_account_credentials: bytes = proto.Field(
        proto.BYTES,
        number=1,
    )


class CreateIntegrationRequest(proto.Message):
    r"""CreateIntegrationRequest is a request to create a new
    integration.

    Attributes:
        collection (str):
            The name of the integration to create.
        integration_id (str):
            ID of the integration to create.
        integration (seqq.api_v1alpha.types.Integration):
            The integration to create.
    """

    collection: str = proto.Field(
        proto.STRING,
        number=1,
    )
    integration_id: str = proto.Field(
        proto.STRING,
        number=2,
    )
    integration: 'Integration' = proto.Field(
        proto.MESSAGE,
        number=3,
        message='Integration',
    )


class UpdateIntegrationRequest(proto.Message):
    r"""UpdateIntegrationRequest is a request to update an
    integration.

    Attributes:
        integration (seqq.api_v1alpha.types.Integration):
            The integration to update.
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            The list of fields to update.
    """

    integration: 'Integration' = proto.Field(
        proto.MESSAGE,
        number=1,
        message='Integration',
    )
    update_mask: field_mask_pb2.FieldMask = proto.Field(
        proto.MESSAGE,
        number=2,
        message=field_mask_pb2.FieldMask,
    )


class GetIntegrationRequest(proto.Message):
    r"""GetIntegrationRequest is the request message for getting an
    integration.

    Attributes:
        name (str):
            The name of the integration to retrieve.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class ListIntegrationsRequest(proto.Message):
    r"""ListIntegrationsRequest is a request to list integrations.

    Attributes:
        collection (str):
            The collection collection of the integrations
            to retrieve.
        page_size (int):
            The maximum number of Integrations to return.
            If unset, at most 50 Integrations will be
            returned. The maximum value is 1000; values
            above 1000 will be coerced to 1000.
        page_token (str):
            A page token, received from a previous List
            Integrations call. Provide this to retrieve the
            subsequent page. When paginating, all other
            parameters provided to ListIntegrations must
            match the call that provided the page token.
    """

    collection: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )


class ListIntegrationsResponse(proto.Message):
    r"""ListIntegrationsResponse holds a list of integrations.

    Attributes:
        integrations (MutableSequence[seqq.api_v1alpha.types.Integration]):
            A list of Integrations in the Collection.
        next_page_token (str):
            A token to retrieve the next page of
            Integrations.
    """

    @property
    def raw_page(self):
        return self

    integrations: MutableSequence['Integration'] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message='Integration',
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


class DeleteIntegrationRequest(proto.Message):
    r"""DeleteIntegrationRequest is the request message for
    DeleteIntegration.

    Attributes:
        name (str):
            The name of the Integration to delete. Format is
            ``collections/{collection_id}/integrations/{integration_id}``.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2023 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

from google.protobuf import duration_pb2  # type: ignore
from google.protobuf import timestamp_pb2  # type: ignore
from google.rpc import status_pb2  # type: ignore
from seqq.api_v1alpha.types import sequence


__protobuf__ = proto.module(
    package='seqq.api.v1alpha',
    manifest={
        'Search',
        'Hit',
        'StartSearchRequest',
        'GetSearchRequest',
        'ListSearchesRequest',
        'ListSearchesResponse',
        'DeleteSearchRequest',
        'Blastn',
        'Blastp',
        'Blastx',
        'Tblastn',
        'Tblastx',
    },
)


class Search(proto.Message):
    r"""A Search of the Sequences in a Collection.

    On creation, Searches direct seqq to start a query against a
    Collection using a chosen ``program``. On reads, Searches contain
    the results of the query, including its current ``state`` and any
    ``hits``.

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        name (str):
            The globally unique name of the Serach. Format is
            ``collections/{collection_id}/searches/{search_id}``.
        query (str):
            The sequence of nucleoties or amino acids to
            search the Collection for.
        code (seqq.api_v1alpha.types.Code):
            The code of the ``sequence``. This is guessed from
            ``sequence`` when unset.
        prefix (str):
            An optional "/" separated prefix to limit
            searches to.
        query_time (google.protobuf.timestamp_pb2.Timestamp):
            The time a search start is started.
        query_duration (google.protobuf.duration_pb2.Duration):
            The duration of a search from start to
            completion.
        hits (MutableSequence[seqq.api_v1alpha.types.Hit]):
            A list of hits from the Search. This is only set when
            ``state`` is ``SUCCEEDED``.
        state (seqq.api_v1alpha.types.Search.State):
            The current state of the Search.
        error (google.rpc.status_pb2.Status):
            The error that occurred during the search. This is only set
            when ``state`` is ``FAILED``.
        blastn (seqq.api_v1alpha.types.Blastn):
            Run a blastn search.

            This field is a member of `oneof`_ ``program``.
        blastp (seqq.api_v1alpha.types.Blastp):
            Run a blastp search.

            This field is a member of `oneof`_ ``program``.
        blastx (seqq.api_v1alpha.types.Blastp):
            Run a blastx search.

            This field is a member of `oneof`_ ``program``.
        tblastn (seqq.api_v1alpha.types.Tblastn):
            Run a tblastn search.

            This field is a member of `oneof`_ ``program``.
        tblastx (seqq.api_v1alpha.types.Tblastx):
            Run a tblastx search.

            This field is a member of `oneof`_ ``program``.
    """
    class State(proto.Enum):
        r"""The current state of the Search.

        Values:
            STATE_UNSPECIFIED (0):
                STATE_UNSPECIFIED is the default value.
            RUNNING (1):
                RUNNING is the search is running.
            SUCCEEDED (2):
                SUCCEEDED is the search succeeded.
            FAILED (3):
                FAILED is the search failed.
        """
        STATE_UNSPECIFIED = 0
        RUNNING = 1
        SUCCEEDED = 2
        FAILED = 3

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    query: str = proto.Field(
        proto.STRING,
        number=2,
    )
    code: sequence.Code = proto.Field(
        proto.ENUM,
        number=3,
        enum=sequence.Code,
    )
    prefix: str = proto.Field(
        proto.STRING,
        number=4,
    )
    query_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=5,
        message=timestamp_pb2.Timestamp,
    )
    query_duration: duration_pb2.Duration = proto.Field(
        proto.MESSAGE,
        number=6,
        message=duration_pb2.Duration,
    )
    hits: MutableSequence['Hit'] = proto.RepeatedField(
        proto.MESSAGE,
        number=7,
        message='Hit',
    )
    state: State = proto.Field(
        proto.ENUM,
        number=8,
        enum=State,
    )
    error: status_pb2.Status = proto.Field(
        proto.MESSAGE,
        number=9,
        message=status_pb2.Status,
    )
    blastn: 'Blastn' = proto.Field(
        proto.MESSAGE,
        number=10,
        oneof='program',
        message='Blastn',
    )
    blastp: 'Blastp' = proto.Field(
        proto.MESSAGE,
        number=11,
        oneof='program',
        message='Blastp',
    )
    blastx: 'Blastp' = proto.Field(
        proto.MESSAGE,
        number=12,
        oneof='program',
        message='Blastp',
    )
    tblastn: 'Tblastn' = proto.Field(
        proto.MESSAGE,
        number=13,
        oneof='program',
        message='Tblastn',
    )
    tblastx: 'Tblastx' = proto.Field(
        proto.MESSAGE,
        number=14,
        oneof='program',
        message='Tblastx',
    )


class Hit(proto.Message):
    r"""Hit is a single hit from a Search.

    Attributes:
        saccver (str):
            Subject accession version.
        pident (float):
            Percentage of identical matches.
        length (int):
            Alignment length.
        mismatch (int):
            Number of mismatches.
        gapopen (int):
            Number of gap openings.
        qstart (int):
            Start of alignment in search.
        qend (int):
            End of alignment in search.
        sstart (int):
            Start of alignment in subject.
        send (int):
            End of alignment in subject.
        evalue (float):
            Expect value.
        bitscore (float):
            Bit score.
    """

    saccver: str = proto.Field(
        proto.STRING,
        number=1,
    )
    pident: float = proto.Field(
        proto.DOUBLE,
        number=2,
    )
    length: int = proto.Field(
        proto.INT64,
        number=3,
    )
    mismatch: int = proto.Field(
        proto.INT64,
        number=4,
    )
    gapopen: int = proto.Field(
        proto.INT64,
        number=5,
    )
    qstart: int = proto.Field(
        proto.INT64,
        number=6,
    )
    qend: int = proto.Field(
        proto.INT64,
        number=7,
    )
    sstart: int = proto.Field(
        proto.INT64,
        number=8,
    )
    send: int = proto.Field(
        proto.INT64,
        number=9,
    )
    evalue: float = proto.Field(
        proto.DOUBLE,
        number=10,
    )
    bitscore: float = proto.Field(
        proto.DOUBLE,
        number=11,
    )


class StartSearchRequest(proto.Message):
    r"""StartSearchRequest is the request message for Search.

    Attributes:
        collection (str):
            The ``name`` of the Collection to search against. Only
            Sequences in this Collection are queried. Format:
            ``collections/{collection_id}``.
        search (seqq.api_v1alpha.types.Search):
            The search parameters to use.
    """

    collection: str = proto.Field(
        proto.STRING,
        number=1,
    )
    search: 'Search' = proto.Field(
        proto.MESSAGE,
        number=2,
        message='Search',
    )


class GetSearchRequest(proto.Message):
    r"""GetSearchRequest gets a currently ongoing search.

    Attributes:
        name (str):
            The name of the Search to retrieve. Format:
            ``collections/{collection_id}/searches/{search_id}``.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class ListSearchesRequest(proto.Message):
    r"""ListSearchesRequest lists searches.

    Attributes:
        collection (str):
            The ``name`` of the Collection to list Searches from.
            Format: ``collections/{collection_id}``.
        page_size (int):
            The maximum number of Searches to return. If
            unset, at most 50 Searches will be returned. The
            maximum value is 1000; values above 1000 will be
            coerced to 1000.
        page_token (str):
            A page token from a previous List Searches
            call. Provide this to retrieve the subsequent
            page. When paginating, all other parameters
            provided to List Searches must match the call
            that provided the page token.
    """

    collection: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )


class ListSearchesResponse(proto.Message):
    r"""ListSearchesResponse is the response message for
    ListSequences.

    Attributes:
        searches (MutableSequence[seqq.api_v1alpha.types.Search]):
            A list of Searches.
        next_page_token (str):
            Next page token is the token to use to
            retrieve the next page of results.
    """

    @property
    def raw_page(self):
        return self

    searches: MutableSequence['Search'] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message='Search',
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


class DeleteSearchRequest(proto.Message):
    r"""DeleteSearchRequest deletes a search.

    Attributes:
        name (str):
            The name of the Search to delete. Format:
            ``collections/{collection_id}/searches/{search_id}``.
        force (bool):
            Whether to return a successful response even
            if the Search does not exist.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    force: bool = proto.Field(
        proto.BOOL,
        number=2,
    )


class Blastn(proto.Message):
    r"""Blastn is a blastn search.
    """


class Blastp(proto.Message):
    r"""Blastp is a blastp search.
    """


class Blastx(proto.Message):
    r"""Blastx is a blastx search.
    """


class Tblastn(proto.Message):
    r"""Tblastn is a tblastn search.
    """


class Tblastx(proto.Message):
    r"""Tblastx is a tblastx search.
    """


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2023 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

from google.protobuf import timestamp_pb2  # type: ignore


__protobuf__ = proto.module(
    package='seqq.api.v1alpha',
    manifest={
        'Code',
        'FileEncoding',
        'Sequence',
        'CreateSequenceRequest',
        'BatchCreateSequencesRequest',
        'BatchCreateSequencesResponse',
        'CreateSequencesFromFileRequest',
        'CreateSequencesFromFileResponse',
        'GetSequenceRequest',
        'ListSequencesRequest',
        'ListSequencesResponse',
        'DeleteSequenceRequest',
    },
)


class Code(proto.Enum):
    r"""Code is the type of sequence.

    Values:
        CODE_UNSPECIFIED (0):
            CODE_UNSPECIFIED is the default value.
        NUCLEIC (1):
            NUCLEIC is a nucleic acid sequence.
        PROTEIN (2):
            PROTEIN is an amino acid sequence.
    """
    CODE_UNSPECIFIED = 0
    NUCLEIC = 1
    PROTEIN = 2


class FileEncoding(proto.Enum):
    r"""FileEncoding is the type of sequence file to upload.

    Values:
        FILE_UNSPECIFIED (0):
            FILE_UNSPECIFIED is the default value.
        FASTA (1):
            FASTA is a FASTA file.
        GENBANK (2):
            GEBANK is a GenBank file.
    """
    FILE_UNSPECIFIED = 0
    FASTA = 1
    GENBANK = 2


class Sequence(proto.Message):
    r"""Sequence is a single entry containing nucleotides or amino
    acids and other optional metadata like a description, creation
    time, and taxonomy ID.

    Attributes:
        name (str):
            Name of the Sequence. Format:
            ``collections/{collection_id}/sequences/{sequence_id}``.
        collection (str):
            The ``name`` of the Collection the Sequence belongs to.
            Format: ``collections/{collection_id}``.
        sequence (str):
            A sequence of nucleotides or amino acids.
            Only characters in the IUPAC alphabets are
            allowed.
        code (seqq.api_v1alpha.types.Code):
            The code of the ``sequence``. This is guessed from
            ``sequence`` when unset.
        taxonomy_id (str):
            The taxonomy ID of the sequence in NCBI's
            Taxonomy database. This can be used to filter
            BLAST search results.
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            The time that the Sequence was created. This
            is set once on creation by the server.
        etag (str):
            An opaque, server-assigned value that is a
            hash of all other fields in the Sequence
            resource. This is used during deletes to ensure
            stale Sequences are excluded from Search
            responses.
        description (str):
            A description of the Sequence. For Sequences
            from FASTA files, this is the entire description
            line without the leading ">". For Sequences from
            GenBank files, this is from the Description
            field.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    collection: str = proto.Field(
        proto.STRING,
        number=2,
    )
    sequence: str = proto.Field(
        proto.STRING,
        number=3,
    )
    code: 'Code' = proto.Field(
        proto.ENUM,
        number=4,
        enum='Code',
    )
    taxonomy_id: str = proto.Field(
        proto.STRING,
        number=5,
    )
    create_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=6,
        message=timestamp_pb2.Timestamp,
    )
    etag: str = proto.Field(
        proto.STRING,
        number=7,
    )
    description: str = proto.Field(
        proto.STRING,
        number=8,
    )


class CreateSequenceRequest(proto.Message):
    r"""CreateSequenceRequest is the request message for
    CreateSequence.

    Attributes:
        collection (str):
            The ``name`` of the Collection to create Sequences in.
            Format: ``collections/{collection_id}``.
        sequence_id (str):
            The ID of the Sequence to create.

            This is appended to the Collection name and ``/sequences/``
            to create the Sequence name.

            For example, if ``collection`` is
            ``collections/my-collection``, and ``sequence_id`` is
            ``my-prefix/my-sequence``, the Sequence name will be
            ``collections/my-collection/sequences/my-prefix/my-sequence``.

            The ``/`` delimiter is encouraged to group Sequences by
            prefix. This is useful in both the UI, where Sequences are
            grouped by folders by ``/``-delimited prefixes, and in
            Searches where a Search can be limited to a subset of
            Sequences by prefix.
        sequence (seqq.api_v1alpha.types.Sequence):
            The Sequence to create.
    """

    collection: str = proto.Field(
        proto.STRING,
        number=1,
    )
    sequence_id: str = proto.Field(
        proto.STRING,
        number=2,
    )
    sequence: 'Sequence' = proto.Field(
        proto.MESSAGE,
        number=3,
        message='Sequence',
    )


class BatchCreateSequencesRequest(proto.Message):
    r"""BatchCreateSequencesRequest specifies how to create a batch
    of sequences at once. Sequences in requests that already exist
    are ignored and not returned in the response.

    Attributes:
        collection (str):
            The ``name`` of the Collection to create Sequences in.
            Format: ``collections/{collection_id}``.
        requests (MutableSequence[seqq.api_v1alpha.types.CreateSequenceRequest]):
            The request message specifying the sequences
            to create. The maximum length is 100.
    """

    collection: str = proto.Field(
        proto.STRING,
        number=1,
    )
    requests: MutableSequence['CreateSequenceRequest'] = proto.RepeatedField(
        proto.MESSAGE,
        number=2,
        message='CreateSequenceRequest',
    )


class BatchCreateSequencesResponse(proto.Message):
    r"""BatchCreateSequencesResponse is the response message for
    BatchCreateSequences.

    Attributes:
        sequences (MutableSequence[seqq.api_v1alpha.types.Sequence]):
            Sequences are the sequences that were
            created.
    """

    sequences: MutableSequence['Sequence'] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message='Sequence',
    )


class CreateSequencesFromFileRequest(proto.Message):
    r"""CreateSequencesFromFileRequest accepts a file and creates
    sequences from it.

    Attributes:
        collection (str):
            The ``name`` of the Collection to create Sequences in.
            Format: ``collections/{collection_id}``.
        sequence_id_prefix (str):
            A prefix to prepend to all sequences in the
            file. Accessions are parsed from the sequence
            file.
        encoding (seqq.api_v1alpha.types.FileEncoding):
            The type of file to parse.
        contents (bytes):
            Content of the file to parse to sequences.
    """

    collection: str = proto.Field(
        proto.STRING,
        number=1,
    )
    sequence_id_prefix: str = proto.Field(
        proto.STRING,
        number=2,
    )
    encoding: 'FileEncoding' = proto.Field(
        proto.ENUM,
        number=3,
        enum='FileEncoding',
    )
    contents: bytes = proto.Field(
        proto.BYTES,
        number=4,
    )


class CreateSequencesFromFileResponse(proto.Message):
    r"""Contains the sequences that were created from the file.

    Attributes:
        sequences (MutableSequence[seqq.api_v1alpha.types.Sequence]):
            Sequences are the sequences that were
            created.
    """

    sequences: MutableSequence['Sequence'] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message='Sequence',
    )


class GetSequenceRequest(proto.Message):
    r"""GetSequenceRequest is the request message for GetSequence.

    Attributes:
        name (str):
            The ``name`` of the Sequence to retrieve. Format:
            ``collections/{collection_id}/sequences/{sequence_id}``.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class ListSequencesRequest(proto.Message):
    r"""ListSequencesRequest is a request to list sequences.

    Attributes:
        collection (str):
            The ``name`` of the Collection to list Sequences from.
            Format: ``collections/{collection_id}``.
        page_size (int):
            The maximum number of Sequences to return.
            seqq may return fewer than this value. If unset,
            at most 50 sequences will be returned. The
            maximum value is 1000; values above 1000 will be
            coerced to 1000.
        page_token (str):
            A page token from a previous List Sequences
            call. Provide this to retrieve the subsequent
            page. When paginating, all other parameters
            provided to List Sequences must match the call
            that provided the page token.
    """

    collection: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )


class ListSequencesResponse(proto.Message):
    r"""ListSequencesResponse is the response message for
    ListSequences.

    Attributes:
        sequences (MutableSequence[seqq.api_v1alpha.types.Sequence]):
            A list of Sequences.
        next_page_token (str):
            Next page token is the token to use to
            retrieve the next page of results.
    """

    @property
    def raw_page(self):
        return self

    sequences: MutableSequence['Sequence'] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message='Sequence',
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


class DeleteSequenceRequest(proto.Message):
    r"""DeleteSequenceRequest is the request message for
    DeleteSequence.

    Attributes:
        name (str):
            The name of the Sequence to delete. Format:
            ``collections/{collection_id}/sequences/{sequence_id}``.
        force (bool):
            Whether to return a successful response even
            if the Sequence does not exist.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    force: bool = proto.Field(
        proto.BOOL,
        number=2,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2023 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore


__protobuf__ = proto.module(
    package='seqq.api.v1alpha',
    manifest={
        'Collection',
        'CreateCollectionRequest',
        'GetCollectionRequest',
        'ListCollectionsRequest',
        'ListCollectionsResponse',
        'DeleteCollectionRequest',
    },
)


class Collection(proto.Message):
    r"""Collections contain Sequences, Searches, and Integration.

    Attributes:
        name (str):
            A globally unique name for the Collection. Format is
            ``collections/{collection_id}`` where ``collection_id`` is
            set during creation. This is not modifiable.
        display_name (str):
            Display name of the collection in the UI. This can differ
            from ``name``. If set, this is used in place of
            ``collection_id`` in the UI.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    display_name: str = proto.Field(
        proto.STRING,
        number=2,
    )


class CreateCollectionRequest(proto.Message):
    r"""CreateCollectionRequest is used to create a collection.

    Attributes:
        collection_id (str):
            ID of the collection to create. Must be
            unique within the parent project. Must be
            between 3 and 64 characters long and can only
            contain alphanumeric characters and hyphens.
        collection (seqq.api_v1alpha.types.Collection):
            Collection to create. Provide ``collection`` when setting
            ``display_name``.
    """

    collection_id: str = proto.Field(
        proto.STRING,
        number=1,
    )
    collection: 'Collection' = proto.Field(
        proto.MESSAGE,
        number=2,
        message='Collection',
    )


class GetCollectionRequest(proto.Message):
    r"""GetCollectionRequest is the request message for
    GetCollection.

    Attributes:
        name (str):
            The name of the Collection to retrieve. Format:
            ``collections/{collection_id}``.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class ListCollectionsRequest(proto.Message):
    r"""ListCollectionsRequest is a request to list collections.

    Attributes:
        page_size (int):
            The maximum number of Collections to return.
            If unset, at most 50 Collections will be
            returned. The maximum value is 1000; values
            above 1000 will be coerced to 1000.
        page_token (str):
            A page token from a previous List Collections
            call. Provide this to retrieve the subsequent
            page.
    """

    page_size: int = proto.Field(
        proto.INT32,
        number=1,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


class ListCollectionsResponse(proto.Message):
    r"""ListCollectionsResponse is the response message for
    ListCollections.

    Attributes:
        collections (MutableSequence[seqq.api_v1alpha.types.Collection]):
            Collections ordered by their name.
        next_page_token (str):
            A token to retrieve the next page of results.
            This is an opaque value that should not be
            parsed. If this is unset, there are no more
            collections to list.
    """

    @property
    def raw_page(self):
        return self

    collections: MutableSequence['Collection'] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message='Collection',
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


class DeleteCollectionRequest(proto.Message):
    r"""DeleteCollectionRequest is the request message for
    DeleteCollection.

    Attributes:
        name (str):
            The name of the collection to delete. Format:
            ``collections/{collection_id}``.
        force (bool):
            Force deletion of the collection even if it
            contains Sequences, Integrations, or Searches.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    force: bool = proto.Field(
        proto.BOOL,
        number=2,
    )


__all__ = tuple(sorted(__protobuf__.manifest))
